/*
** Module   : OuterFrame.java
** Abstract : Simple top-level window.
**
** Copyright (c) 2010-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 SIY 20100629 Created initial version
** 002 SIY 20100804 Changes in imports, some refactorings.
** 003 SIY 20110112 Changes related to new color handling scheme.
** 004 CA  20140805 Added generics to force the abstract widget classes to not use implementation-
**                  specific code: the abstract widgets will have access only to the base APIs
**                  provided by the OutputManager.
**                  ChuiOutputManager is explicitly imported, to fine track the ChUI dependencies.
** 005 CA  20141119 Refactored drawing code to enable multiple OS windows, for GUI support.  Misc
**                  changes/fixes related to drawing on multiple windows.
** 006 EVL 20150424 Making the class GUI compatible.
** 007 EVL 20140613 Separating common drawing routine into protected method to avoid ChUI calls
**                  from GUI code.
*/

package com.goldencode.p2j.ui.client.widget;

import com.goldencode.p2j.ui.*;
import com.goldencode.p2j.ui.client.*;
import com.goldencode.p2j.ui.client.chui.driver.ChuiOutputManager;

/**
 * Simple top level frame.
 */
public class OuterFrame<O extends OutputManager<?>>
extends TitledWindow<O>
{
   /**
    * Constructor.
    * 
    * @param   title
    *          Frame title.
    */
   public OuterFrame(String title)
   {
      super(title, new Insets(1, 1, 1, 1));
   }

   /**
    * Constructor.
    * 
    * @param   insets
    *          Frame insets.
    */
   public OuterFrame(Insets insets)
   {
      super(null, insets);
   }
   
   /**
    * Draw widget.
    */
   @Override
   public void draw()
   {
      // get the current client mode
      boolean isChui = OutputManager.instance().isChui();
      
      if (isChui)
      {
         Color color = Color.DEFAULT;
         clear(location(), dimension(), color);

         if (insets().top != 0 && insets().bottom != 0)
         {
            // TODO: remove this dependency
            ((ChuiOutputManager) screen()).box(location(), dimension(), color);
         }

         if (hasTitle())
         {
            // TODO: remove this dependency
            ((ChuiOutputManager) screen()).at(location().offset(1, 0))
                                          .append(' ', color)
                                          .append(title(), color)
                                          .append(' ', color);
         }
      }

      drawInt();
   }

   /**
    * Internal drawing routine for common UI code.
    */
   protected void drawInt()
   {
      super.draw();
   }
}
